@@ -385,7 +385,7 @@ async def get_transcript(
                 if i.embeds:
                     for e in i.embeds:
                         (r, g, b) = (
-                            tuple(int(hex(e.color).lstrip("0x")[i : i + 2], 16) for i in (0, 2, 4))
+                            ((e.color >> 16) & 255, (e.color >> 8) & 255, e.color & 255)
                             if e.color
                             else (0x20, 0x22, 0x25)
                         )
